@@ -36,6 +36,8 @@ from ..usecases.crop_weed_detection import CropWeedDetectionUseCase, CropWeedDet
 from ..usecases.child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
 from ..usecases.gender_detection import GenderDetectionConfig, GenderDetectionUseCase
 from ..usecases.weapon_detection import WeaponDetectionUseCase,WeaponDetectionConfig
+from ..usecases.concrete_crack_detection import ConcreteCrackUseCase, ConcreteCrackConfig
+from ..usecases.fashion_detection import FashionDetectionUseCase, FashionDetectionConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -69,7 +71,8 @@ __all__ = [
     'ChildMonitoringUseCase',
     'GenderDetectionUseCase',
     'WeaponDetectionUseCase',
-
+    'ConcreteCrackUseCase',
+    'FashionDetectionUseCase',
 
 
 
@@ -104,4 +107,6 @@ __all__ = [
     'ChildMonitoringConfig',
     'GenderDetectionConfig',
     'WeaponDetectionConfig',
+    'ConcreteCrackConfig',
+    'FashionDetectionConfig'
 ]
