@@ -413,7 +413,9 @@ class ConfigManager:
             "emergency_vehicle_detection": None,
             "price_tag_detection": None,
             "child_monitoring": None,
-            "weapon_tracking" : None
+            "weapon_tracking" : None,
+            "concrete_crack_detection": None,
+            "fashion_detection": None,
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -620,6 +622,22 @@ class ConfigManager:
             return GenderDetectionConfig
         except ImportError:
             return None
+    
+    def concrete_crack_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.concrete_crack_detection import ConcreteCrackConfig
+            return ConcreteCrackConfig
+        except ImportError:
+            return None
+        
+    def fashion_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.fashion_detection import FashionDetectionConfig
+            return FashionDetectionConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -1155,6 +1173,38 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "concrete_crack_detection":
+            # Import here to avoid circular import
+            from ..usecases.concrete_crack_detection import ConcreteCrackConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = ConcreteCrackConfig(
+                category=category or "general",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
+        elif usecase == "fashion_detection":
+            # Import here to avoid circular import
+            from ..usecases.fashion_detection import FashionDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = FashionDetectionConfig(
+                category=category or "retail",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1400,6 +1450,16 @@ class ConfigManager:
             from ..usecases.gender_detection import GenderDetectionConfig
             default_config = GenderDetectionConfig()
             return default_config.to_dict()
+        elif usecase == "concrete_crack_detection":
+            # Import here to avoid circular import
+            from ..usecases.concrete_crack_detection import ConcreteCrackConfig
+            default_config = ConcreteCrackConfig()
+            return default_config.to_dict()
+        elif usecase == "fashion_detection":
+            # Import here to avoid circular import
+            from ..usecases.fashion_detection import FashionDetectionConfig
+            default_config = FashionDetectionConfig()
+            return default_config.to_dict()
 
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
