@@ -60,7 +60,9 @@ from .usecases import (
     SolarPanelUseCase,
     CropWeedDetectionUseCase,
     ChildMonitoringUseCase,
-    GenderDetectionUseCase
+    GenderDetectionUseCase,
+    ConcreteCrackUseCase,
+    FashionDetectionUseCase
 
 
 )
@@ -155,6 +157,8 @@ class PostProcessor:
         registry.register_use_case("security", "child_monitoring", ChildMonitoringUseCase)
         registry.register_use_case("general", "gender_detection", GenderDetectionUseCase)
         registry.register_use_case("security", "weapon_tracking", WeaponDetectionUseCase)
+        registry.register_use_case("general", "concrete_crack_detection", ConcreteCrackUseCase)
+        registry.register_use_case("retail", "fashion_detection", FashionDetectionUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -269,6 +273,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, GenderDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, FashionDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
             
