@@ -1,35 +1,23 @@
-"""
-child Monitoring Use Case for Post-Processing
-
-This module provides child monitoring functionality with congestion detection,
-zone analysis, and alert generation.
-
-"""
-
 from typing import Any, Dict, List, Optional
-from dataclasses import asdict
+from dataclasses import dataclass, field
 import time
+from collections import deque
 from datetime import datetime, timezone
 
-from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol, ResultFormat
+from ..core.base import BaseProcessor, ProcessingContext, ProcessingResult, ConfigProtocol
+from ..core.config import BaseConfig, AlertConfig
 from ..utils import (
     filter_by_confidence,
-    filter_by_categories,
-    apply_category_mapping,
-    count_objects_by_category,
-    count_objects_in_zones,
     calculate_counting_summary,
     match_results_structure,
+    apply_category_mapping,
     bbox_smoothing,
     BBoxSmoothingConfig,
     BBoxSmoothingTracker
 )
-from dataclasses import dataclass, field
-from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class ChildMonitoringConfig(BaseConfig):
-    """Configuration for child detection use case in child monitoring."""
     # Smoothing configuration
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"  # "window" or "observability"
@@ -37,25 +25,18 @@ class ChildMonitoringConfig(BaseConfig):
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
     
-    # child confidence thresholds
-    confidence_threshold: float = 0.6
-
+    # Violation thresholds
+    # no_hardhat_threshold: float = 0.91
+    # no_mask_threshold: float = 0.4
+    # no_safety_vest_threshold: float = 0.4
     
-    child_categories: List[str] = field(
-        default_factory=lambda: ['baby']
-    )
-
-    target_child_categories: List[str] = field(
-        default_factory=lambda: ['baby']
-    )
-
-
+    child_categories: List[str] = field(default_factory=lambda: [
+        "baby"
+    ])
     alert_config: Optional[AlertConfig] = None
-    index_to_category: Optional[Dict[int, str]] = field(
-        default_factory=lambda: {
-            0: "baby"
-        }
-    )
+    index_to_category: Optional[Dict[int, str]] = field(default_factory=lambda: {
+        0: 'baby'
+    })
 
 class ChildMonitoringUseCase(BaseProcessor):
     def _get_track_ids_info(self, detections: list) -> Dict[str, Any]:
@@ -123,37 +104,42 @@ class ChildMonitoringUseCase(BaseProcessor):
             filtered.append(detections[best_idx])
             used[best_idx] = True
         return filtered
-
     def _update_child_tracking_state(self, detections: list):
         """
         Track unique child track_ids per category for total count after tracking.
-        Applies canonical ID merging to avoid duplicate counting when the underlying
-        tracker loses an object temporarily and assigns a new ID.
         """
-        # Lazily initialise storage dicts
-        if not hasattr(self, "_child_total_track_ids"):
-            self._child_total_track_ids = {cat: set() for cat in self.child_categories}
+        self._child_total_track_ids = getattr(self, '_child_total_track_ids', {cat: set() for cat in self.child_categories})
         self._child_current_frame_track_ids = {cat: set() for cat in self.child_categories}
-
         for det in detections:
-            cat = det.get("category")
-            raw_track_id = det.get("track_id")
-            if cat not in self.child_categories or raw_track_id is None:
-                continue
-            bbox = det.get("bounding_box", det.get("bbox"))
-            canonical_id = self._merge_or_register_track(raw_track_id, bbox)
-            # Propagate canonical ID back to detection so downstream logic uses it
-            det["track_id"] = canonical_id
-
-            self._child_total_track_ids.setdefault(cat, set()).add(canonical_id)
-            self._child_current_frame_track_ids[cat].add(canonical_id)
+            cat = det.get('category')
+            track_id = det.get('track_id')
+            if cat in self.child_categories and track_id is not None:
+                self._child_total_track_ids[cat].add(track_id)
+                self._child_current_frame_track_ids[cat].add(track_id)
 
     def get_total_child_counts(self):
         """
         Return total unique track_id count for each child category.
         """
         return {cat: len(ids) for cat, ids in getattr(self, '_child_total_track_ids', {}).items()}
-    
+    """child detection use case with violation smoothing and alerting."""
+
+    def __init__(self):
+        super().__init__("child_monitoring")
+        self.category = "security"
+        # List of child categories to track
+        self.child_categories = ["baby"]
+        # Initialize smoothing tracker
+        self.smoothing_tracker = None
+        # Initialize advanced tracker (will be created on first use)
+        self.tracker = None
+        # Initialize tracking state variables
+        self._total_frame_counter = 0
+        self._global_frame_offset = 0
+        # Set of current frame track_ids (updated per frame)
+        self._current_frame_track_ids = set()
+        # Track start time for "TOTAL SINCE" calculation
+        self._tracking_start_time = None
     def _format_timestamp_for_video(self, timestamp: float) -> str:
         """Format timestamp for video chunks (HH:MM:SS.ms format)."""
         hours = int(timestamp // 3600)
@@ -170,30 +156,23 @@ class ChildMonitoringUseCase(BaseProcessor):
         """Get formatted current timestamp based on stream type."""
         if not stream_info:
             return "00:00:00.00"
-        
         is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
-        
         # if is_video_chunk:
-        #     # For video chunks, use video_timestamp from stream_info
         #     video_timestamp = stream_info.get("video_timestamp", 0.0)
         #     return self._format_timestamp_for_video(video_timestamp)
-        if stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
+        if stream_info.get("input_settings", {}).get("stream_type", "video_file") == "video_file":
             # If video format, return video timestamp
             stream_time_str = stream_info.get("video_timestamp", "")
             return stream_time_str[:8]
         else:
-            # For streams, use stream_time from stream_info
             stream_time_str = stream_info.get("stream_time", "")
             if stream_time_str:
-                # Parse the high precision timestamp string to get timestamp
                 try:
-                    # Remove " UTC" suffix and parse
                     timestamp_str = stream_time_str.replace(" UTC", "")
                     dt = datetime.strptime(timestamp_str, "%Y-%m-%d-%H:%M:%S.%f")
                     timestamp = dt.replace(tzinfo=timezone.utc).timestamp()
                     return self._format_timestamp_for_stream(timestamp)
                 except:
-                    # Fallback to current time if parsing fails
                     return self._format_timestamp_for_stream(time.time())
             else:
                 return self._format_timestamp_for_stream(time.time())
@@ -202,76 +181,32 @@ class ChildMonitoringUseCase(BaseProcessor):
         """Get formatted start timestamp for 'TOTAL SINCE' based on stream type."""
         if not stream_info:
             return "00:00:00"
-        
         is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
-        
         if is_video_chunk:
-            # For video chunks, start from 00:00:00
             return "00:00:00"
-        elif stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
+        elif stream_info.get("input_settings", {}).get("stream_type", "video_file") == "video_file":
             # If video format, start from 00:00:00
             return "00:00:00"
         else:
-            # For streams, use tracking start time or current time with minutes/seconds reset
             if self._tracking_start_time is None:
-                # Try to extract timestamp from stream_time string
                 stream_time_str = stream_info.get("stream_time", "")
                 if stream_time_str:
                     try:
-                        # Remove " UTC" suffix and parse
                         timestamp_str = stream_time_str.replace(" UTC", "")
                         dt = datetime.strptime(timestamp_str, "%Y-%m-%d-%H:%M:%S.%f")
                         self._tracking_start_time = dt.replace(tzinfo=timezone.utc).timestamp()
                     except:
-                        # Fallback to current time if parsing fails
                         self._tracking_start_time = time.time()
                 else:
                     self._tracking_start_time = time.time()
-            
             dt = datetime.fromtimestamp(self._tracking_start_time, tz=timezone.utc)
-            # Reset minutes and seconds to 00:00 for "TOTAL SINCE" format
             dt = dt.replace(minute=0, second=0, microsecond=0)
             return dt.strftime('%Y:%m:%d %H:%M:%S')
 
-    """child Monitoring use case with child smoothing and alerting."""
-
-    def __init__(self):
-        super().__init__("child_monitoring")
-        self.category = "security"
-        
-        # List of child categories to track
-        self.child_categories = ['baby']
-        
-        # Initialize smoothing tracker
-        self.smoothing_tracker = None
-        
-        # Initialize advanced tracker (will be created on first use)
-        self.tracker = None
-        
-        # Initialize tracking state variables
-        self._total_frame_counter = 0
-        self._global_frame_offset = 0
-
-        # Track start time for "TOTAL SINCE" calculation
-        self._tracking_start_time = None
-
-        # ------------------------------------------------------------------ #
-        # Canonical tracking aliasing to avoid duplicate counts              #
-        # ------------------------------------------------------------------ #
-        # Maps raw tracker-generated IDs to stable canonical IDs that persist
-        # even if the underlying tracker re-assigns a new ID after a short
-        # interruption. This mirrors the logic used in people_counting to
-        # provide accurate unique counting.
-        self._track_aliases: Dict[Any, Any] = {}
-        self._canonical_tracks: Dict[Any, Dict[str, Any]] = {}
-        # Tunable parameters – adjust if necessary for specific scenarios
-        self._track_merge_iou_threshold: float = 0.05  # IoU ≥ 0.05 → same child
-        self._track_merge_time_window: float = 7.0    # seconds within which to merge
-
     def process(self, data: Any, config: ConfigProtocol, context: Optional[ProcessingContext] = None, stream_info: Optional[Dict[str, Any]] = None) -> ProcessingResult:
         """
-        Main entry point for child Monitoring post-processing.
-        Applies category mapping, child smoothing, counting, alerting, and summary generation.
+        Main entry point for child detection post-processing.
+        Applies category mapping, violation smoothing, counting, alerting, and summary generation.
         Returns a ProcessingResult with all relevant outputs.
         """
         start_time = time.time()
@@ -284,24 +219,14 @@ class ChildMonitoringUseCase(BaseProcessor):
         # Detect input format and store in context
         input_format = match_results_structure(data)
         context.input_format = input_format
-        context.confidence_threshold = config.confidence_threshold
-
-        if config.confidence_threshold is not None:
-                processed_data = filter_by_confidence(data, config.confidence_threshold)
-                self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
-        else:
-                processed_data = data
-                self.logger.debug(f"Did not apply confidence filtering with threshold since nothing was provided")
-            
-        # Step 2: Apply category mapping if provided
-        if config.index_to_category:
-                processed_data = apply_category_mapping(processed_data, config.index_to_category)
-                self.logger.debug("Applied category mapping")
+        # context.no_hardhat_threshold = config.no_hardhat_threshold
 
 
-        if config.target_child_categories:
-                processed_data = [d for d in processed_data if d.get('category') in self.child_categories]
-                self.logger.debug(f"Applied child category filtering")
+
+        # Map detection indices to category names robustly (child only)
+        processed_data = self._robust_apply_category_mapping(data, config.index_to_category)
+        # Only keep child categories (remove 'Person', etc.)
+        processed_data = [d for d in processed_data if d.get('category') in self.child_categories]
 
         # Apply bbox smoothing if enabled
         if config.enable_smoothing:
@@ -310,7 +235,7 @@ class ChildMonitoringUseCase(BaseProcessor):
                     smoothing_algorithm=config.smoothing_algorithm,
                     window_size=config.smoothing_window_size,
                     cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=config.confidence_threshold,  # Use mask threshold as default
+                    confidence_threshold=config.no_mask_threshold,  # Use mask threshold as default
                     confidence_range_factor=config.smoothing_confidence_range_factor,
                     enable_smoothing=True
                 )
@@ -327,7 +252,7 @@ class ChildMonitoringUseCase(BaseProcessor):
             if self.tracker is None:
                 tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
-                self.logger.info("Initialized AdvancedTracker for child Monitoring and tracking")
+                self.logger.info("Initialized AdvancedTracker for childs tracking")
             
             # The tracker expects the data in the same format as input
             # It will add track_id and frame_id to each detection
@@ -338,11 +263,11 @@ class ChildMonitoringUseCase(BaseProcessor):
             self.logger.warning(f"AdvancedTracker failed: {e}")
 
         # Deduplicate overlapping childs (same label, high IoU)
-        # processed_data = self._deduplicate_childs(processed_data, iou_thresh=0.95)
+        # processed_data = self._deduplicate_childs(processed_data, iou_thresh=0.92)
 
         # Update child tracking state for total count per label
         self._update_child_tracking_state(processed_data)
-        
+
         # Update frame counter
         self._total_frame_counter += 1
 
@@ -368,8 +293,8 @@ class ChildMonitoringUseCase(BaseProcessor):
         summary = self._generate_summary(counting_summary, alerts)
 
         # Step: Generate structured events and tracking stats with frame-based keys
-        events_list = self._generate_events(counting_summary, alerts, config, frame_number,stream_info)
-        tracking_stats_list = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number,stream_info)
+        events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
+        tracking_stats_list = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number, stream_info)
 
         # Extract frame-based dictionaries from the lists
         events = events_list[0] if events_list else {}
@@ -409,124 +334,68 @@ class ChildMonitoringUseCase(BaseProcessor):
             self.tracker.reset()
             self.logger.info("AdvancedTracker reset for new tracking session")
     
-    def reset_child_tracking(self) -> None:
+    def reset_violation_tracking(self) -> None:
         """
-        Reset child tracking state (total counts, track IDs, etc.).
+        Reset violation tracking state (total counts, track IDs, etc.).
+        
+        This should be called when:
+        - Starting a completely new tracking session
+        - Switching to a different video/stream
+        - Manual reset requested by user
         """
-        self._child_total_track_ids = {cat: set() for cat in self.child_categories}
+        self._violation_total_track_ids = {cat: set() for cat in self.child_categories}
         self._total_frame_counter = 0
         self._global_frame_offset = 0
         self._tracking_start_time = None
-        # Also clear canonical tracking structures
-        self._track_aliases.clear()
-        self._canonical_tracks.clear()
-        self.logger.info("child Monitoring tracking state reset")
-    
+        self.logger.info("child violation tracking state reset")
+
     def reset_all_tracking(self) -> None:
         """
-        Reset both advanced tracker and child tracking state.
+        Reset both advanced tracker and violation tracking state.
         """
         self.reset_tracker()
-        self.reset_child_tracking()
-        self.logger.info("All childs tracking state reset")
+        self.reset_violation_tracking()
+        self.logger.info("All PPE tracking state reset")
         
     def _generate_events(self, counting_summary: Dict, alerts: List, config: ChildMonitoringConfig, frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
         """Generate structured events for the output format with frame-based keys."""
-        from datetime import datetime, timezone
-
         # Use frame number as key, fallback to 'current_frame' if not available
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         events = [{frame_key: []}]
         frame_events = events[0][frame_key]
         total_childs = counting_summary.get("total_count", 0)
 
+        # Generate human text in new format
+        human_text_lines = ["EVENTS DETECTED:"]
         if total_childs > 0:
-            # Determine event level based on thresholds
-            level = "info"
-            intensity = 5.0
-            if config.alert_config and config.alert_config.count_thresholds:
-                threshold = config.alert_config.count_thresholds.get("all", 15)
-                intensity = min(10.0, (total_childs / threshold) * 10)
-                
-                if intensity >= 7:
-                    level = "critical"
-                elif intensity >= 5:
-                    level = "warning"
-                else:
-                    level = "info"
-            else:
-                if total_childs > 25:
-                    level = "critical"
-                    intensity = 9.0
-                elif total_childs > 15:
-                    level = "warning" 
-                    intensity = 7.0
-                else:
-                    level = "info"
-                    intensity = min(10.0, total_childs / 3.0)
-
-            # Generate human text in new format
-            human_text_lines = ["EVENTS DETECTED:"]
-            human_text_lines.append(f"    - {total_childs} child(s) detected [INFO]")
-            human_text = "\n".join(human_text_lines)
+            human_text_lines.append(f"\t- {total_childs} childs(s) detected [INFO]")
+        else:
+            human_text_lines.append("\t- No childs detected")
+        human_text = "\n".join(human_text_lines)
 
+        if total_childs > 0:
             event = {
                 "type": "child_monitoring",
-                "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
-                "level": level,
-                "intensity": round(intensity, 1),
-                "config": {
-                    "min_value": 0,
-                    "max_value": 10,
-                    "level_settings": {"info": 2, "warning": 5, "critical": 7}
-                },
-                "application_name": "child Monitoring System",
-                "application_version": "1.2",
+                "severity": "info",
+                "category": "security",
+                "count": total_childs,
+                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
                 "location_info": None,
                 "human_text": human_text
             }
             frame_events.append(event)
-
         # Add alert events
         for alert in alerts:
-            total_childs = counting_summary.get("total_count", 0)
-            intensity_message = "ALERT: Low congestion in the scene"
-            if config.alert_config and config.alert_config.count_thresholds:
-                threshold = config.alert_config.count_thresholds.get("all", 15)
-                percentage = (total_childs / threshold) * 100 if threshold > 0 else 0
-                if percentage < 20:
-                    intensity_message = "ALERT: Low congestion in the scene"
-                elif percentage <= 50:
-                    intensity_message = "ALERT: Moderate congestion in the scene"
-                elif percentage <= 70:
-                    intensity_message = "ALERT: Heavy congestion in the scene"
-                else:
-                    intensity_message = "ALERT: Severe congestion in the scene"
-            else:
-                if total_childs > 15:
-                    intensity_message = "ALERT: Heavy congestion in the scene"
-                elif total_childs == 1:
-                    intensity_message = "ALERT: Low congestion in the scene"
-                else:
-                    intensity_message = "ALERT: Moderate congestion in the scene"
-
             alert_event = {
-                "type": alert.get("type", "congestion_alert"),
-                "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
-                "level": alert.get("severity", "warning"),
-                "intensity": 8.0,
-                "config": {
-                    "min_value": 0,
-                    "max_value": 10,
-                    "level_settings": {"info": 2, "warning": 5, "critical": 7}
-                },
-                "application_name": "Congestion Alert System",
-                "application_version": "1.2",
+                "type": alert.get("type", "alert"),
+                "severity": alert.get("severity", "warning"),
+                "category": alert.get("category", "child"),
+                "count": alert.get("current_count", 0),
+                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
                 "location_info": alert.get("zone"),
-                "human_text": f"{datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')} : {intensity_message}"
+                "human_text": alert.get("human_text", "child alert triggered")
             }
             frame_events.append(alert_event)
-
         return events
 
     def _generate_tracking_stats(
@@ -546,10 +415,9 @@ class ChildMonitoringUseCase(BaseProcessor):
         frame_tracking_stats = tracking_stats[0][frame_key]
 
         total_childs = counting_summary.get("total_count", 0)
-        total_child_counts = counting_summary.get("total_child_counts", {})
-        cumulative_total = sum(total_child_counts.values()) if total_child_counts else 0
-        per_category_count = counting_summary.get("per_category_count", {})
-
+        per_cat = counting_summary.get("per_category_count", {})
+        cumulative = counting_summary.get("total_child_counts", {})
+        cumulative_total = sum(cumulative.values()) if cumulative else 0
 
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
 
@@ -561,33 +429,31 @@ class ChildMonitoringUseCase(BaseProcessor):
         # CURRENT FRAME section
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
         if total_childs > 0:
-            category_counts = [f"{count} {cat}" for cat, count in per_category_count.items()]
-            if len(category_counts) == 1:
-                childs_text = category_counts[0] + " detected"
-            elif len(category_counts) == 2:
-                childs_text = f"{category_counts[0]} and {category_counts[1]} detected"
-            else:
-                childs_text = f"{', '.join(category_counts[:-1])}, and {category_counts[-1]} detected"
-            human_text_lines.append(f"\t- {childs_text}")
+            human_text_lines.append(f"\t- Total childs Detected: {total_childs}")
+            for cat in ["child"]:
+                count = per_cat.get(cat, 0)
+                if count > 0:
+                    label = self.CATEGORY_DISPLAY.get(cat, cat).replace(" childs", "")
+                    human_text_lines.append(f"\t\t- {label}: {count}")
         else:
-            human_text_lines.append(f"\t- No childs detected")
+            human_text_lines.append("\t- No childs detected")
 
         human_text_lines.append("")  # spacing
 
         # TOTAL SINCE section
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
         human_text_lines.append(f"\t- Total childs Detected: {cumulative_total}")
-        # Add category-wise child counts
-        if total_child_counts:
-            for cat, count in total_child_counts.items():
-                if count > 0:  # Only include categories with non-zero counts
-                    human_text_lines.append(f"\t- {cat}: {count}")
+        for cat in ["child"]:
+            count = cumulative.get(cat, 0)
+            if count > 0:
+                label = self.CATEGORY_DISPLAY.get(cat, cat).replace(" childs", "")
+                human_text_lines.append(f"\t\t- {label}: {count}")
 
         human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
             "type": "child_monitoring",
-            "category": "security",
+            "category": "general",
             "count": total_childs,
             "insights": insights,
             "summary": summary,
@@ -610,66 +476,41 @@ class ChildMonitoringUseCase(BaseProcessor):
         counts = {}
         for det in detections:
             cat = det.get('category', 'unknown')
-            counts[cat] = counts.get(cat, 0) + 1
+            if cat in self.child_categories:
+                counts[cat] = counts.get(cat, 0) + 1
         # Each detection dict will now include 'track_id' (and possibly 'frame_id')
+        filtered_detections = [
+            {
+                "bounding_box": det.get("bounding_box"),
+                "category": det.get("category"),
+                "confidence": det.get("confidence"),
+                "track_id": det.get("track_id"),
+                "frame_id": det.get("frame_id")
+            }
+            for det in detections if det.get('category') in self.child_categories
+        ]
         return {
             "total_count": sum(counts.values()),
             "per_category_count": counts,
-            "detections": [
-                {
-                    "bounding_box": det.get("bounding_box"),
-                    "category": det.get("category"),
-                    "confidence": det.get("confidence"),
-                    "track_id": det.get("track_id"),
-                    "frame_id": det.get("frame_id")
-                }
-                for det in detections
-            ]
+            "detections": filtered_detections
         }
 
-    # Human-friendly display names for child categories
+    # Human-friendly display names for violation categories
+    # CATEGORY_DISPLAY = {
+    #     "NO-Hardhat": "No Hardhat childs",
+    #     "NO-Mask": "No Mask childs",
+    #     "NO-Safety Vest": "No Safety Vest childs"
+    # }
     CATEGORY_DISPLAY = {
-        "Baby": "baby"
-        }
+        "baby": "Baby",
+    }
 
     def _generate_insights(self, summary: dict, config: ChildMonitoringConfig) -> List[str]:
         """
-        Generate human-readable insights for each child category.
+        Generate human-readable insights for each violation category.
         """
         insights = []
         per_cat = summary.get("per_category_count", {})
-        total_childs = summary.get("total_count", 0)
-
-        if total_childs == 0:
-            insights.append("No childs detected in the scene")
-            return insights
-        insights.append(f"EVENT: Detected {total_childs} childs in the scene")
-        # Intensity calculation based on threshold percentage
-        intensity_threshold = None
-        if (config.alert_config and 
-            config.alert_config.count_thresholds and 
-            "all" in config.alert_config.count_thresholds):
-            intensity_threshold = config.alert_config.count_thresholds["all"]
-        
-        if intensity_threshold is not None:
-            # Calculate percentage relative to threshold
-            percentage = (total_childs / intensity_threshold) * 100
-            
-            if percentage < 20:
-                insights.append(f"INTENSITY: Low congestion in the scene ({percentage:.1f}% of capacity)")
-            elif percentage <= 50:
-                insights.append(f"INTENSITY: Moderate congestion in the scene ({percentage:.1f}% of capacity)")
-            elif percentage <= 70:
-                insights.append(f"INTENSITY:  Heavy congestion in the scene ({percentage:.1f}% of capacity)")
-            else:
-                insights.append(f"INTENSITY: Severe congestion in the scene ({percentage:.1f}% of capacity)")
-        # else:
-        #     # Fallback to hardcoded thresholds if no alert config is set
-        #     if total_childs > 15:
-        #         insights.append(f"INTENSITY: Heavy congestion in the scene with {total_childs} childs")
-        #     elif total_childs == 1:
-        #         insights.append(f"INTENSITY: Low congestion in the scene")
-
         for cat, count in per_cat.items():
             display = self.CATEGORY_DISPLAY.get(cat, cat)
             insights.append(f"{display}:{count}")
@@ -687,26 +528,16 @@ class ChildMonitoringUseCase(BaseProcessor):
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category == "all" and total >= threshold:
                     timestamp = datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
-                    alert_description = f"childs count ({total}) exceeds threshold ({threshold})"
+                    alert_description = f"Child count ({total}) exceeds threshold ({threshold})"
                     alerts.append({
                         "type": "count_threshold",
                         "severity": "warning",
-                        "message": f"Total child count ({total}) exceeds threshold ({threshold})",
+                        "message": alert_description,
                         "category": category,
                         "current_count": total,
-                        "threshold": threshold
+                        "threshold": threshold,
+                        "human_text": f"Time: {timestamp}\n{alert_description}"
                     })
-                elif category in summary.get("per_category_count", {}):
-                    count = summary.get("per_category_count", {})[category]
-                    if count >= threshold:
-                        alerts.append({
-                            "type": "count_threshold",
-                            "severity": "warning",
-                            "message": f"{category} count ({count}) exceeds threshold ({threshold})",
-                            "category": category,
-                            "current_count": count,
-                            "threshold": threshold
-                        })
         return alerts
 
     def _extract_predictions(self, detections: list) -> List[Dict[str, Any]]:
@@ -725,12 +556,12 @@ class ChildMonitoringUseCase(BaseProcessor):
     def _generate_summary(self, summary: dict, alerts: List) -> str:
         """
         Generate a human_text string for the result, including per-category insights if available.
-        Adds a tab before each child label for better formatting.
-        Also always includes the cumulative child count so far.
+        Adds a tab before each violation label for better formatting.
+        Also always includes the cumulative violation count so far.
         """
         total = summary.get("total_count", 0)
         per_cat = summary.get("per_category_count", {})
-        cumulative = summary.get("total_child_counts", {}) 
+        cumulative = summary.get("total_violation_counts", {})
         cumulative_total = sum(cumulative.values()) if cumulative else 0
         lines = []
         if total > 0:
@@ -738,118 +569,41 @@ class ChildMonitoringUseCase(BaseProcessor):
             if per_cat:
                 lines.append("childs:")
                 for cat, count in per_cat.items():
-                    lines.append(f"\t{cat}:{count}")
+                    display = self.CATEGORY_DISPLAY.get(cat, cat)
+                    label = display.replace("Baby", "baby")
+                    if count == 1:
+                        lines.append(f"\t{label}")
+                    else:
+                        lines.append(f"\t{label}:{count}")
         else:
-            lines.append("No child detected")
-        lines.append(f"Total childs detected: {cumulative_total}")
+            lines.append("child detected")
+        lines.append(f"Total child detected: {cumulative_total}")
         if alerts:
             lines.append(f"{len(alerts)} alert(s)")
         return "\n".join(lines)
 
-    # ------------------------------------------------------------------ #
-    # Canonical ID helpers                                               #
-    # ------------------------------------------------------------------ #
-    def _compute_iou(self, box1: Any, box2: Any) -> float:
-        """Compute IoU between two bounding boxes which may be dicts or lists.
-        Falls back to 0 when insufficient data is available."""
-        # Helper to convert bbox (dict or list) to [x1, y1, x2, y2]
-        def _bbox_to_list(bbox):
-            if bbox is None:
-                return []
-            if isinstance(bbox, list):
-                return bbox[:4] if len(bbox) >= 4 else []
-            if isinstance(bbox, dict):
-                if "xmin" in bbox:
-                    return [bbox["xmin"], bbox["ymin"], bbox["xmax"], bbox["ymax"]]
-                if "x1" in bbox:
-                    return [bbox["x1"], bbox["y1"], bbox["x2"], bbox["y2"]]
-                # Fallback: first four numeric values
-                values = [v for v in bbox.values() if isinstance(v, (int, float))]
-                return values[:4] if len(values) >= 4 else []
-            return []
-
-        l1 = _bbox_to_list(box1)
-        l2 = _bbox_to_list(box2)
-        if len(l1) < 4 or len(l2) < 4:
-            return 0.0
-        x1_min, y1_min, x1_max, y1_max = l1
-        x2_min, y2_min, x2_max, y2_max = l2
-
-        # Ensure correct order
-        x1_min, x1_max = min(x1_min, x1_max), max(x1_min, x1_max)
-        y1_min, y1_max = min(y1_min, y1_max), max(y1_min, y1_max)
-        x2_min, x2_max = min(x2_min, x2_max), max(x2_min, x2_max)
-        y2_min, y2_max = min(y2_min, y2_max), max(y2_min, y2_max)
-
-        inter_x_min = max(x1_min, x2_min)
-        inter_y_min = max(y1_min, y2_min)
-        inter_x_max = min(x1_max, x2_max)
-        inter_y_max = min(y1_max, y2_max)
-
-        inter_w = max(0.0, inter_x_max - inter_x_min)
-        inter_h = max(0.0, inter_y_max - inter_y_min)
-        inter_area = inter_w * inter_h
-
-        area1 = (x1_max - x1_min) * (y1_max - y1_min)
-        area2 = (x2_max - x2_min) * (y2_max - y2_min)
-        union_area = area1 + area2 - inter_area
-
-        return (inter_area / union_area) if union_area > 0 else 0.0
-
-    def _merge_or_register_track(self, raw_id: Any, bbox: Any) -> Any:
-        """Return a stable canonical ID for a raw tracker ID, merging fragmented
-        tracks when IoU and temporal constraints indicate they represent the
-        same physical child."""
-        if raw_id is None or bbox is None:
-            # Nothing to merge
-            return raw_id
-
-        now = time.time()
-
-        # Fast path – raw_id already mapped
-        if raw_id in self._track_aliases:
-            canonical_id = self._track_aliases[raw_id]
-            track_info = self._canonical_tracks.get(canonical_id)
-            if track_info is not None:
-                track_info["last_bbox"] = bbox
-                track_info["last_update"] = now
-                track_info["raw_ids"].add(raw_id)
-            return canonical_id
-
-        # Attempt to merge with an existing canonical track
-        for canonical_id, info in self._canonical_tracks.items():
-            # Only consider recently updated tracks
-            if now - info["last_update"] > self._track_merge_time_window:
-                continue
-            iou = self._compute_iou(bbox, info["last_bbox"])
-            if iou >= self._track_merge_iou_threshold:
-                # Merge
-                self._track_aliases[raw_id] = canonical_id
-                info["last_bbox"] = bbox
-                info["last_update"] = now
-                info["raw_ids"].add(raw_id)
-                return canonical_id
-
-        # No match – register new canonical track
-        canonical_id = raw_id
-        self._track_aliases[raw_id] = canonical_id
-        self._canonical_tracks[canonical_id] = {
-            "last_bbox": bbox,
-            "last_update": now,
-            "raw_ids": {raw_id},
-        }
-        return canonical_id
-    
-    def _format_timestamp(self, timestamp: float) -> str:
-        """Format a timestamp for human-readable output."""
-        return datetime.fromtimestamp(timestamp, timezone.utc).strftime('%Y-%m-%d %H:%M:%S UTC')
-
-    def _get_tracking_start_time(self) -> str:
-        """Get the tracking start time, formatted as a string."""
-        if self._tracking_start_time is None:
-            return "N/A"
-        return self._format_timestamp(self._tracking_start_time)
-
-    def _set_tracking_start_time(self) -> None:
-        """Set the tracking start time to the current time."""
-        self._tracking_start_time = time.time()
+    def _robust_apply_category_mapping(self, data, index_to_category):
+        """
+        Map detection indices to category names, robustly handling int or numeric string indices.
+        Only for PPE use case to avoid affecting other use cases.
+        Handles both int and str keys in index_to_category.
+        """
+        mapped = []
+        if data:
+            for det in data:
+                mapped_det = det.copy()
+                cat = det.get("category")
+                # Convert string numbers to int if possible
+                if isinstance(cat, str) and cat.isdigit():
+                    cat_int = int(cat)
+                else:
+                    cat_int = cat
+                mapped_label = None
+                if cat_int in index_to_category:
+                    mapped_label = index_to_category[cat_int]
+                elif isinstance(cat_int, int) and str(cat_int) in index_to_category:
+                    mapped_label = index_to_category[str(cat_int)]
+                if mapped_label is not None:
+                    mapped_det["category"] = mapped_label
+                mapped.append(mapped_det)
+        return mapped
