@@ -32,7 +32,7 @@ class TheftDetectionConfig(BaseConfig):
     target_theft_categories: List[str] = field(default_factory=lambda: ['shoplifting'])
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
-        default_factory=lambda: {0: "normal", 1: "shoplifting"}
+        default_factory=lambda: {-1: "normal", 0: "shoplifting"}
     )
 
 class TheftDetectionUseCase(BaseProcessor):
